@@ -1,6 +1,10 @@
 #ifndef CORBA_STRING_H
 #define CORBA_STRING_H 1
 
+#include <glib.h>
+
+G_BEGIN_DECLS
+
 CORBA_char  *CORBA_string_alloc  (CORBA_unsigned_long len);
 CORBA_wchar *CORBA_wstring_alloc (CORBA_unsigned_long len);
 
@@ -9,6 +13,8 @@ CORBA_wchar *CORBA_wstring_alloc (CORBA_unsigned_long len);
  */
 CORBA_char          *CORBA_string_dup  (const CORBA_char *str);
 
+CORBA_wchar         *CORBA_wstring_dup (const CORBA_wchar *str);
+
 CORBA_unsigned_long  CORBA_wstring_len (CORBA_wchar *ws);
 
 #ifdef ORBIT2_INTERNAL_API
@@ -21,4 +27,6 @@ CORBA_sequence_CORBA_octet *
 
 #endif /* ORBIT2_INTERNAL_API */
 
+G_END_DECLS
+
 #endif
