@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  * Author: Phil Dawes <philipd@users.sourceforge.net>
  */
@@ -203,7 +203,7 @@ POA_test_AnyServer__epv AnyServer_epv = {
 	AnyServer_opAnyLong,
 	AnyServer_opAnyString,
 	AnyServer_opAnyStruct,
-	AnyServer_opTypeCode,
+	AnyServer_opTypeCode
 };
 
 PortableServer_ServantBase__epv AnyServer_base_epv = {NULL, simple_finalize, NULL};
