@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  * Author: Phil Dawes <philipd@users.sourceforge.net>
  */
@@ -37,7 +37,7 @@
 #ifdef TIMING_RUN
 #  define d_print(a)
 #else
-#  define d_print(a) if (!thread_tests) g_print(a)
+#  define d_print(a) if (!thread_tests && a != NULL) g_print(a)
 #endif
 
 extern CORBA_ORB global_orb;
@@ -1957,7 +1957,7 @@ static void
 wait_until_done (void)
 {
 	while (!done)
-		g_main_iteration (TRUE);
+		g_main_context_iteration (NULL, TRUE);
 }
 
 static void
@@ -2034,7 +2034,6 @@ testPingPong (test_TestFactory   factory,
 
 
 	test_PingPongServer_pingPong (r_objref, l_objref, 64, ev);
-	d_print (CORBA_exception_id (ev));
 	g_assert (ev->_major == CORBA_NO_EXCEPTION);
 	
 	d_print ("Testing ping pong reg / lookup ...\n");
@@ -2557,6 +2556,8 @@ main (int argc, char *argv [])
 	char              *orb_name;
 	int                i;
 
+	g_thread_init (NULL);
+
 	CORBA_exception_init (ev);
 
 /* FIXME - make this work nicely sometime.
